@@ -46,6 +46,10 @@ file_exists(const char *fn)
 {
         struct stat sbuf;
 
+	if (g_file_test(fn, G_FILE_TEST_IS_DIR)) {
+		return FALSE;
+	}
+
         return (stat(fn, &sbuf) == 0);
 }
 
@@ -150,7 +154,7 @@ main(int argc, const char **argv)
                 }
                 if(i >= ndirs) {
                         printf ("<HTML><HEAD><TITLE>Document not found</TITLE>\n"
-                                "</HEAD><BODY BGCOLOR=\"#FFFFFF\">The info document \"%s\" could not be found. It may have been removed from your system.\n"
+                                "</HEAD><BODY>The info document \"%s\" could not be found. It may have been removed from your system.\n"
                                 "</BODY></HTML>\n", args[0]);
                         return 2;
                 }
@@ -216,7 +220,7 @@ main(int argc, const char **argv)
 	work_line_number = 0;
 
 	/* hack, just send to stdout for now */
-	fprintf(stdout, "<HTML><BODY BGCOLOR=\"#ffffff\">\n");
+	g_print("<HTML><HEAD><TITLE>Info page for \"%s\"</TITLE></BODY><BODY>\n", argv[1]);
 	
 	/* big loop to identify sections of info files */
 	/* NEW PLAN - format on the fly */
